@@ -2,6 +2,7 @@ from Microsoft.Finance.DataStandards.UnitTest.TestCase.BridgeTestCase import Bri
 from Microsoft.Finance.DataStandards.UnitTest.TestCase.CommonTestCase import CommonTestCase
 from Microsoft.Finance.DataStandards.UnitTest.TestSuite.BaseTestSuite import BaseTestSuite
 from pyspark.sql.session import SparkSession
+from unittest import TestLoader
 
 class BridgeTestSuite(BaseTestSuite):
 
@@ -15,12 +16,17 @@ class BridgeTestSuite(BaseTestSuite):
     #region Class Methods
 
     def queue_tests(self) -> None:
-        bridgeTestCase = BridgeTestCase(self.FieldInfo, self.CustomEvents)
-        commonTestCase = CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents)
-        self.TestSuite.addTest(bridgeTestCase)
-        self.TestSuite.addTest(commonTestCase)
 
-    def run_tests(self) -> None:
-        self.TestRunner(self.TestSuite)
+        loader = TestLoader()
+
+        names = loader.getTestCaseNames(BridgeTestCase)
+
+        for name in names:
+            self.TestSuite.addTest(BridgeTestCase(self.FieldInfo, self.CustomEvents, name))
+
+        names = loader.getTestCaseNames(CommonTestCase)
+
+        for name in names:
+            self.TestSuite.addTest(CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents, name))
 
     #endregion
\ No newline at end of file
